#ifndef Cache_h
#define Cache_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "File.h"
#include "RevisionCache.h"
#include "FileInfoCache.h"

//* store list of file info and cvs information. Used for cache.
class Cache: public Counter
{

    public:

    //* constructor
    Cache(): Counter( "Cache" )
    {}

    //* read from file
    bool read( File file = File() );

    //* write to file
    bool write( File file = File() ) const;

    //* file info cache
    const FileInfoCache& fileInfoCache( void ) const
    { return fileInfoCache_; }

    //* file info cache
    void setFileInfoCache( const FileInfoCache& cache )
    { fileInfoCache_ = cache; }

    //* revision cache
    const RevisionCache& revisionCache( void ) const
    { return revisionCache_; }

    //* revision cache
    void setRevisionCache( const RevisionCache& cache )
    { revisionCache_ = cache; }

    //* clear
    void clear( void )
    {
        fileInfoCache_.clear();
        revisionCache_.clear();
    }

    private:

    //* associated file where information is to be stored; if any
    File file_;

    //* file info cache
    FileInfoCache fileInfoCache_;

    //* revision cache
    RevisionCache revisionCache_;

};

#endif
