/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TextEditor.h"
#include "CvsCommitDialog.h"
#include "TreeView.h"

#include <QLabel>

//____________________________________________________________________________
QString CvsCommitDialog::savedComments_;

//____________________________________________________________________________
CvsCommitDialog::CvsCommitDialog( QWidget* parent, const FileInfo& path ):
    FileSelectionDialog( parent )
{

    Debug::Throw( "CvsCommitDialog::CvsCommitDialog.\n" );

    // insert path in list
    _model().add( path );
    _list().selectionModel()->select( _model().index( path ), QItemSelectionModel::SelectCurrent|QItemSelectionModel::Rows );

    // comments editor
    _workLayout().addWidget( new QLabel( tr( "Comments:" ), this ) );
    _workLayout().addWidget( editor_ = new TextEditor( this ), 1 );
    editor().setWrapFromOptions( false );
    editor().wrapModeAction().setChecked( true );
    editor().setAcceptRichText( false );
    editor().setPlainText( savedComments_ );

    okButton().setText( tr( "Commit" ) );
    okButton().setToolTip( tr( "Commit selected files to the repository" ) );
    connect( &okButton(), SIGNAL(clicked()), SLOT(_saveComments()) );
    okButton().setFocus();
    adjustSize();
}

//____________________________________________________________________________
CvsCommitDialog::CvsCommitDialog( QWidget* parent, const FileInfoModel::List& files ):
    FileSelectionDialog( parent, files )
{

    Debug::Throw( "CvsCommitDialog::CvsCommitDialog.\n" );

    // comments editor
    _workLayout().addWidget( new QLabel( tr( "Comments:" ), this ) );
    _workLayout().addWidget( editor_ = new TextEditor( this ), 1 );
    editor().setWrapFromOptions( false );
    editor().wrapModeAction().setChecked( true );
    editor().setAcceptRichText( false );
    editor().setPlainText( savedComments_ );

    okButton().setText( tr( "Commit" ) );
    okButton().setToolTip( tr( "Commit selected files to the repository" ) );
    connect( &okButton(), SIGNAL(clicked()), SLOT(_saveComments()) );
    adjustSize();
}

//____________________________________________________________________________
void CvsCommitDialog::_saveComments( void )
{
    Debug::Throw( "CvsCommitDialog::_saveComments.\n" );
    savedComments_ = editor().toPlainText();
}
