#ifndef HelpText_h
#define HelpText_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include <QObject>
#include <QString>

//* help text
static const QString helpText[] =
{

    //_________________________________________________________
    QObject::tr( "Introduction" ),
    QObject::tr( "<h2>Introduction</h2>"
    "<p>Cvswatch is an interface to cvs (Concurrent versions system), that allows to easily check and modify the status of "
    "files that are stored both locally and remotely inside a cvs repository. It interacts with cvs in the background to check "
    "the current status of local files against the repository and displays dedicated icons accordingly. It allows to update local "
    "files from the repository, add new files to the repository or remove existing files from it, as well as commit local "
    "modifications to the repository.</p>" ),

    //___________________
    QObject::tr( "Main window" ),
    QObject::tr( "<h2>Main window</h2>"
    "<p>The main window consists of the following frames:</p>"

    "<h3>File editor</h3>"
    "<p>The file editor is a single read-only text line that displays the current path and selected file of the application. A busy indicator is located at its right, that appears rotating when a cvs task is executed in the background. Pressing on the busy indicator forces a refresh of the entire window.</p>"

    "<h3>File browser</h3>"
    "<p>The file browser is a list of the files and directories located in the current application directory. Files are represented with a dedicated icon that reflects its local status with respect to the matching repository file. Double-clicking on a folder allows to navigate the directory tree. Selecting a file in the list updates the file editor bar, and retrieves the available revisions for this file from the repository. These revisions are listed in the revision frame. A popup menu appear when right-clicking in the list to display the available cvs commands as well as some additional file management actions.</p>"

    "<h3>Revision browser</h3>"
    "<p>The revision browser displays the available revisions for the current file as it appears in the <i>file editor</i>. When a revision is selected in the list, its associated comments are shown in the <i>Comments editor</i>. A popup menu is raised when right-clicking in the list. It displays the following actions:</p>"
    "<ul>"
    "<li><i>Edit local file</i>, to edit the current file using the associated text edition application that can be set in the <i>Configuration</i> dialog;</li>"
    "<li><i>Edit revision</i>, to check-out and edit the selected revision in the list using the associated text edition application that can be set in the <i>Configuration</i> dialog. The revision is first checked-out from the repository and saved to a local file whose name is constructed from the original file-name and the revision number;</li>"
    "<li><i>Diff local and revision</i>, to edit both the local file and the selected revision and diff them, using the associated text edition application that can be set in the <i>Configuration</i> dialog.</li>"
    "</ul>"
    "<p>The same actions are available using buttons located below the <i>Comments editor</i></p>"

    "<h3>Toolbars</h3>"
    "<p>Two toolbars are available at the top of the main window. The first toolbar allows to navigate the directory tree in the file browser. The second contains shortcut to the following two cvs commands: <i>update directory</i> and <i>commit directory</i>. These commands apply to the entire directory that is currently displayed in the file browser, disregarding whether files are selected or not in this list.</p>"

    "<h3>Comments frame</h3>"
    "<p>The comments frame is located below the <i>revision browser</i> and displays the comments associated to the current revision selected in the selection browser</i>.</p>"

    "<h3>Command list</h3>"
    "<p>The command list is located on the right side of the main window and displays the list of pending cvs commands. Commands are removed from the list as soon as they are either aborted or completed. By default the command list is hidden. It can be made visible either by changing the corresponding option in the <i>Configuration</i> dialog or using the corresponding button in the <i>Settings</i> menu.</p>"

    "<h3>Log frame</h3>"
    "<p>The log frame is located at the bottom of the main window and displays informations about the cvs tasks that are currently being executed. It can be shown/hidden using the corresponding toggle button in the <i>Settings</i> menu. Its default visibility when the application starts is set in the <i>Configuration</i> dialog.</p>" ),

    //___________________
    QObject::tr( "Icon signification" ),
    QObject::tr( "<h2>Icon signification</h2>"
    "<p>Shown below are the various icons that appear together with the filenames in the <i>File browser</i> and their signification in terms of status with respect to the cvs repository.</p>"
    "<p><img src=\":/pixmaps/up_to_date.png\" />&nbsp;"
    "The local file is up-to-date with respect to the repository"
    "</p>"
    "<p><img src=\":/pixmaps/merge.png\" />&nbsp;"
    "The file has been modified both locally and in the repository and the modifications must be merged"
    "</p>"
    "<p><img src=\":/pixmaps/conflict.png\" />&nbsp;"
    "The file has been modified both locally and in the repository and there is a conflict between the two sets of modifications"
    "</p>"
    "<p><img src=\":/pixmaps/remotely_modified.png\"/>&nbsp;"
    "The file has been remotely modified but has not been updated locally"
    "</p>"
    "<p><img src=\":/pixmaps/remotely_added.png\"/>&nbsp;"
    "The file is present in the repository but cannot be found locally"
    "</p>"
    "<p><img src=\":/pixmaps/remotely_removed.png\"/>&nbsp;"
    "The file has been remotely removed from the repository but not locally"
    "</p>"
    "<p><img src=\":/pixmaps/locally_modified.png\" />&nbsp;"
    "The file has been locally modified but the change has not been committed"
    "</p>"
    "<p><img src=\":/pixmaps/locally_added.png\"/>&nbsp;"
    "The file has been added to the repository but the change has not been committed"
    "</p>"
    "<p><img src=\":/pixmaps/locally_removed.png\"/>&nbsp;"
    "The file has been removed from disk and from the repository but the change has not been committed"
    "</p>"
    "<p><img src=\":/pixmaps/unknown.png\" />&nbsp;"
    "There is no information about the local file in the repository"
    "</p>" ),

    //___________________
    QObject::tr( "Cvs commands" ),
    QObject::tr( "<h2>Cvs commands</h2"
    "<p>Cvs commands are available in a pop-up menu when right-clicking in the file browser on the left of the main window. Following commands are available:</p>"
    "<ul>"
    "<li><i>cvs checkout</i>, used to checkout one or several modules from the repository. A dialog is opened that enables to select the root path of the cvs repository, the name of the module(s) to be checked out (module names must be separated by a \",\"), and a possible alternative path to save the module in the local directory. The later option is naturally disabled when several modules are checked-out simultaneously. By default (meaning: if no alternative path is provided), the same directory structure is used locally as in the repository, starting from the directory from where the check-out is performed.</li>"
    "<li><i>cvs update</i>, used to update the selected files with respect to the repository;</li>"
    "<li><i>cvs update directory</i>, used to update the entire local directory with respect to the repository;</li>"
    "<li><i>cvs add</i>, used to schedule the addition of the selected local files to the repository. <i>cvs commit</i> must be called after <i>add</i> to actually commit the added files to the repository</li>;"
    "<li><i>cvs remove</i>, to schedule the removal of the selected local files from the repository. The selected files are first either locally renamed or removed prior to removing them from the repository. <i>cvs commit</i> must be called after <i>add</i> to actually commit the removed files to the repository</li>;"
    "<li><i>cvs commit</i>, used to commit the scheduled changes to the selected files (either addition, removal or modifications) to the repository.</i>"
    "<li><i>cvs commit directory</i>, used to commit the scheduled changes to all files in the current directory (either addition, removal or modifications) to the repository.</i>"
    "</ul>"
    "<p>For the <i>add</i>, <i>remove</i> and <i>commit</i> actions, a dialog is opened that duplicates the list of selected items in the file browser. It allows to select the items to which the requested action applies, and tune the cvs command options.</p>"

    "<h3>Additional file management commands</h3>"
    "The following <i>file management</i> commands are also available in the same menu, that are independent from cvs:</p>"
    "<ul>"
    "<li><i>Edit</i>, used to edit the selected local files using the associated text edition application that can be set in the <i>Configuration</i> dialog;</li>"
    "<li><i>Remove</i>, used to remove the selected files from the local disk (this does not interact with the repository);</li>"
    "<li><i>Show hidden files</i>, used to show/hide the hidden files in the browser.</li>"
    "</ul>" ),

    //___________________
    QObject::tr( "Locks" ),
    QObject::tr( "<h2>Locks</h2>"
    "<p>It sometimes happen that a cvs command cannot be executed properly due to a lock file found in the repository that prevents editing of the repository or even checking files out of it. This is notably the case when someone else performs actions remotely that affect the content of the repository. When such things occur, a pop-up dialog opens that notify the user about the lock. The locked command can then be aborted or the notification can be ignored. In both cases the user has to take care manually of either removing the lock from the repository or waiting for it to be automatically removed.</p>" ),

    //___________________
    QObject::tr( "Log verbosity" ),
    QObject::tr( "<h2>Log verbosity</h2>"
    "<p>The log verbosity refers to the amount of details that is displayed in the <i>Log</i> frame located at the bottom of the main window. It can be changed either directly from the <i>Settings</i> menu or in the <i>Configuration</i> dialog.</p>"
    "<p>Two verbosity modes are currently available.</p>"
    "<h3>Low verbosity</h3>"
    "<p>In low verbosity mode, the outputs from cvs commands are parsed and only a reduced/condensed subset of it is displayed in the log, such as the current status of the local files with respect to the repository; the available revision numbers, author and dates for a given file; the existence of a lock in a given repository; etc. Also displayed, enclosed within brackets, are information of the current cvs command being executed and its completion status.</p>"
    "<h3>High verbosity</h3>"
    "<p>In high verbosity mode, all outputs from cvs are displayed in the log, together with the low verbosity information. Both standard and <i>error</i> output are displayed. They appear in italic in the log. The standard output is appears in black, whereas error messages (as decided by cvs) appear in red.</p>" ),

    0
};

#endif
