#ifndef RevisionCache_h
#define RevisionCache_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "File.h"
#include "Revision.h"

#include <QDomDocument>
#include <QDomElement>
#include <QMap>

//! store map of files and associated revisions. Used for cache.
class RevisionCache: public QMap< File, Revision::List >, public Counter
{

    public:

    //! constructor
    RevisionCache( void ):
        Counter( "RevisionCache" )
    {}

    //! constructor from Dom Element
    RevisionCache( const QDomElement& );

    //! write dom element
    QDomElement domElement( QDomDocument& parent ) const;

    //! used to remove first created elements from cache
    class FirstCreatedFTor
    {

        public:

        //! prediction
        bool operator() (const Revision::List& first, const Revision::List& second )
        { return first.created() < second.created(); }

    };

    //! maximum size
    RevisionCache& setMaximumSize( int size )
    {
        maxSize_ = size;
        return truncate();
    }

    //! truncate to maximum size
    RevisionCache& truncate( void );

    private:

    //! maximum cache size
    /*!
    negative means no limit.
    0 means chache is not used.
    */
    int maxSize_;

};

#endif
