/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ViewModeMenu.h"

#include "Application.h"
#include "Debug.h"
#include "FileSelectionFrame.h"
#include "MainWindow.h"

//_____________________________________________
ViewModeMenu::ViewModeMenu( QWidget* parent ):
QMenu( parent ),
Counter( "ViewModeMenu" )
{
    Debug::Throw( "ViewModeMenu::ViewModeMenu.\n" );
    actionGroup_ = new QActionGroup( this );
    connect( this, SIGNAL(aboutToShow()), SLOT(_update()) );
    connect( this, SIGNAL(triggered(QAction*)), SLOT(_selectViewMode(QAction*)) );
}

//_____________________________________________
void ViewModeMenu::_update( void )
{
    Debug::Throw( "ViewModeMenu::_update.\n" );

    // clear menu
    clear();
    actions_.clear();

    // retrieve current class from MainWindow
    MainWindow& window( *static_cast<MainWindow*>( parentWidget()->window()) );
    FileSelectionFrame::ViewMode viewMode( window.selectionFrame().viewMode() );

    // insert actions
    {
        QAction* action = addAction( tr( "Icons" ) );
        action->setCheckable( true );
        action->setChecked( viewMode == FileSelectionFrame::Icons );
        actionGroup_->addAction( action );
        actions_.insert( action, FileSelectionFrame::Icons );
    }

    // insert actions
    {
        QAction* action = addAction( tr( "Details" ) );
        action->setCheckable( true );
        action->setChecked( viewMode == FileSelectionFrame::List );
        actionGroup_->addAction( action );
        actions_.insert( action, FileSelectionFrame::List );
    }

}

//_____________________________________________
void ViewModeMenu::_selectViewMode( QAction* action )
{
    Debug::Throw( "ViewModeMenu::_selectViewMode.\n" );
    ActionMap::iterator iter = actions_.find( action );
    if( iter != actions_.end() )
    { emit viewModeSelected( iter.value() ); }

    return;

}
